# Overview

- This charm installs and configures the Kaminario storage driver as the backend for OpenStack Cinder.

- It prepares Cinder to use the Kaminario driver as block storage.

- This charm supports Trusty and Xenial releases of Ubuntu.

# Usage

 This charm can be deployed in one of the following ways:

- Using the Juju GUI

- Using the CLI (from the public charm store)

- Using the CLI (from the local repository)

## Deployment of Charm

### Using the Juju GUI:

  - From the machine on which the Juju environment is deployed, open the web browser.

  - Open the Juju GUI web page.

  - From "Search", run "Kaminario-cinder".

  - Click the "Add to Canvas" tab.

  - Select the Charm icon and click "Configure" to modify the charm configuration parameters.

  - Click "Save the changes".

  - Add the relation of the charm with Cinder.

  - Add the relation of the charm with Nova-compute.

  - Click "Deploy changes".

  - Click "Deploy".

### Using the CLI (from the public charm store):

  - Open the web browser and go to the Juju Charm store page.

  - From "Search", run "kaminario-cinder".

  - Open the Kaminario-openstack charm. 

  - Select and copy the text shown in the "juju deploy charm-name" text box located at the top right corner of the page. Paste the copied text into the command line of the 

terminal on which you have configured the Juju environment and then run it.

####Example:

    juju deploy cs:~kaminario/kaminario-cinder

#### Set the configuration values for the Charm:

##### If you are using Juju version 2.X:

    juju set-config kaminario-cinder san_user="san username" \
	san_password="san password" san_ip="san IP" \
	backend_name="kaminario-fc" protocol="fc" 

    juju config kaminario-cinder san_user="san username" \
	san_password="san password" san_ip="san IP" \
	backend_name="kaminario-fc" protocol="fc"

   **NOTE:** The " juju config" works in Juju 2.0-beta18 and the above versions, and the "juju set-config" works in Juju 2.0-beta15 and the earlier versions.

   **NOTE:** For more configuration options, refer to the "Configuration" section in the same page.  

##### If you are using Juju version 1.X:

    juju service set kaminario-cinder san_user="san username" \
	san_password="san password" san_ip="san IP" \
	backend_name="kaminario-fc" protocol="fc"

#####  Add the relation of the charm with Cinder and Nova-compute:

    juju add-relation kaminario-cinder cinder

    juju add-relation kaminario-cinder nova-compute

### Using the CLI (from the local repository):

  - Open the web browser and go to the Juju charm store page.

  - From "Search", run "kaminario-cinder".

  - Click the "Download as zip" button and copy the zipped folder to the machine on which the Juju environment is deployed.  

  - Open the command line terminal and unzip the folder.

#### Deploy the charm from the local repository:

##### If you are using Juju version 2.X:

    juju deploy path_to_charm_folder --series=os_release_name

###### Example:

    juju deploy ~/kaminario-cinder --series=xenial

    juju deploy ~/kaminario-cinder --series=trusty

##### If you are using Juju version 1.X:

    juju deploy --repository=path_to_charm_parent_folder \
	local:os_release_name/charm_folder_name

###### Example:

    juju deploy --repository=~/src/charms local:trusty/kaminario-cinder

#### Set the configuration values for the charm:

##### If you are using Juju version 2.X:

    juju set-config kaminario-cinder san_user="san username" \
	san_password="san password" san_ip="san IP" backend_name="kaminario-fc" protocol="fc"

    juju config kaminario-cinder san_user="san username" \
	san_password="san password" san_ip="san IP" backend_name="kaminario-fc" protocol="fc"

**NOTE:** The " juju config" works in Juju 2.0-beta18 and the above versions, and the "juju set-config" works in Juju 2.0-beta15 and the earlier versions.

##### If you are using Juju version 1.X:

     juju service set kaminario-cinder san_user="san username" \
	san_password="san password" san_ip="san san IP" backend_name="kaminario-fc" protocol="fc"

#### Add the relation for the charm with Cinder and Nova-compute:

     juju add-relation kaminario-cinder cinder

     juju add-relation kaminario-cinder nova-compute

## Charm Removal 

### Remove the charm using the following:

#### If you are using Juju version 2.X:

        juju remove-application kaminario-cinder

#### If you are using Juju version 1.X:

         juju remove-service kaminario-cinder or juju destroy-service kaminario-cinder

# Additional Information

  - You can deploy the same charm with multiple applications. This is useful if someone wants to configure Cinder and Nova-compute using the same charm with different 

application names.


## Deploy the charm with different application names:

    juju deploy charm-name app1

    juju deploy charm-name app2

    juju deploy charm-name app3

## Set the configuration values for the charm:

    juju set-config app1 san_ip=192.168.0.1 san_user=admin1 \
	san_password=password1 backend_name=kaminario-iscsi protocol=iscsi 

    juju set-config app2 san_ip=192.168.0.2 san_user=admin2 \
	san_password=password2 backend_name=kaminario-iscsi protocol=iscsi

    juju set-config app3 is_multipath_enabled=True

## Add the relation of the charm with Cinder:

    juju add-relation cinder app1

    juju add-relation cinder app2

    juju add-relation nova-compute app3

### Example:

#### For juju 2.0:

    juju deploy cs:~kaminario/kaminario-cinder  app1

    juju set-config app1 san_ip=192.168.0.1 san_user=admin1 \
	san_password=password1 backend_name=kaminario-iscsi protocol=iscsi 

    juju add-relation app1 cinder

#### For juju 1.25:

    juju deploy juju deploy cs:~kaminario/kaminario-cinder app1

    juju service set app1 san_ip=10.0.0.1 san_user=admin1 \
	san_password=password1 backend_name=kaminario-iscsi protocol=iscsi

    juju add-relation app1 cinder

